@@ -19,13 +19,12 @@ import sahara.exceptions as ex
 from sahara.i18n import _
 import sahara.plugins.base as plugin_base
 import sahara.service.api as api
-from sahara.service import ops
 import sahara.service.validations.base as b
-import sahara.service.validations.cluster_templates as cl_t
+import sahara.service.validations.cluster_template_schema as ct_schema
 
 
 def _build_node_groups_schema():
-    schema = copy.deepcopy(cl_t.CLUSTER_TEMPLATE_SCHEMA)
+    schema = copy.deepcopy(ct_schema.CLUSTER_TEMPLATE_SCHEMA)
     return schema['properties']['node_groups']
 
 
@@ -70,35 +69,38 @@ CLUSTER_SCALING_SCHEMA = {
 
 def check_cluster_scaling(data, cluster_id, **kwargs):
     cluster = api.get_cluster(id=cluster_id)
-
+    if cluster is None:
+        raise ex.NotFoundException(
+            {'id': cluster_id}, _('Object with %s not found'))
     cluster_engine = cluster.sahara_info.get(
         'infrastructure_engine') if cluster.sahara_info else None
 
+    engine_type_and_version = api.OPS.get_engine_type_and_version()
     if (not cluster_engine and
-            not ops.get_engine_type_and_version().startswith('direct')):
-        raise ex.InvalidException(
+            not engine_type_and_version.startswith('direct')):
+        raise ex.InvalidReferenceException(
             _("Cluster created before Juno release "
               "can't be scaled with %(engine)s engine") %
-            {"engine": ops.get_engine_type_and_version()})
+            {"engine": engine_type_and_version})
 
     if (cluster.sahara_info and
-            cluster_engine != ops.get_engine_type_and_version()):
-        raise ex.InvalidException(
+            cluster_engine != engine_type_and_version):
+        raise ex.InvalidReferenceException(
             _("Cluster created with %(old_engine)s infrastructure engine "
               "can't be scaled with %(new_engine)s engine") %
             {"old_engine": cluster.sahara_info.get('infrastructure_engine'),
-             "new_engine": ops.get_engine_type_and_version()})
+             "new_engine": engine_type_and_version})
 
     if not (plugin_base.PLUGINS.is_plugin_implements(cluster.plugin_name,
                                                      'scale_cluster') and (
             plugin_base.PLUGINS.is_plugin_implements(cluster.plugin_name,
                                                      'decommission_nodes'))):
-        raise ex.InvalidException(
+        raise ex.InvalidReferenceException(
             _("Requested plugin '%s' doesn't support cluster scaling feature")
             % cluster.plugin_name)
 
     if cluster.status != 'Active':
-        raise ex.InvalidException(
+        raise ex.InvalidReferenceException(
             _("Cluster cannot be scaled not in 'Active' status. "
               "Cluster status: %s") % cluster.status)
 
@@ -107,6 +109,7 @@ def check_cluster_scaling(data, cluster_id, **kwargs):
 
     if data.get("add_node_groups"):
         b.check_add_node_groups(cluster, data['add_node_groups'])
-        b.check_network_config(data['add_node_groups'])
+        b.check_network_config(data['add_node_groups'],
+                               cluster.has_proxy_gateway())
         b.check_cluster_hostnames_lengths(cluster.name,
                                           data['add_node_groups'])
