@@ -12,9 +12,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from tempest.lib.common.utils import data_utils
-
-from sahara.tests.tempest.scenario.data_processing.client_tests import base
+from tempest.scenario.data_processing.client_tests import base
+from tempest import test
+from tempest_lib.common.utils import data_utils
 
 
 class JobBinariesTest(base.BaseDataProcessingTest):
@@ -68,15 +68,6 @@ class JobBinariesTest(base.BaseDataProcessingTest):
         self.assertEqual(binary_name, binary.name)
         self.assertDictContainsSubset(self.swift_job_binary, binary.__dict__)
 
-    def _check_swift_job_binary_update(self, binary_id):
-        values = {
-            'url': 'swift://user/foo',
-            'description': 'description'
-        }
-        # check updating of job binary in swift
-        binary = self.client.job_binaries.update(binary_id, values)
-        self.assertDictContainsSubset(values, binary.__dict__)
-
     def _check_internal_db_job_binary_create(self):
         name = data_utils.rand_name('sahara-internal-job-binary')
         self.job_binary_data = 'Some data'
@@ -104,29 +95,21 @@ class JobBinariesTest(base.BaseDataProcessingTest):
         self.assertEqual(binary_name, binary.name)
         self.assertDictContainsSubset(self.internal_db_binary, binary.__dict__)
 
-    def _check_internal_db_job_binary_update(self, binary_id):
-        values = {
-            'description': 'description'
-        }
-        # check updating of job binary in internal db
-        binary = self.client.job_binaries.update(binary_id, values)
-        self.assertDictContainsSubset(values, binary.__dict__)
-
     def _check_job_binary_get_file(self, binary_id):
         data = self.client.job_binaries.get_file(binary_id)
         self.assertEqual(self.job_binary_data, data)
 
+    @test.services('data_processing')
     def test_swift_job_binaries(self):
         binary_id, binary_name = self._check_swift_job_binary_create()
         self._check_job_binary_list(binary_id, binary_name)
         self._check_swift_job_binary_get(binary_id, binary_name)
-        self._check_swift_job_binary_update(binary_id)
         self._check_job_binary_delete(binary_id)
 
+    @test.services('data_processing')
     def test_internal_job_binaries(self):
         binary_id, binary_name = self._check_internal_db_job_binary_create()
         self._check_job_binary_list(binary_id, binary_name)
         self._check_internal_db_job_binary_get(binary_id, binary_name)
         self._check_job_binary_get_file(binary_id)
-        self._check_internal_db_job_binary_update(binary_id)
         self._check_job_binary_delete(binary_id)
